#!/bin/bash

# spdx-license-identifier: gpl-3.0-only
# Copyright (C) 2022 Michał Góral

[[ -n "$LIBGPAK_SEND_SH" ]] && return
LIBGPAK_SEND_SH=1

source "${LIBRARY}/message.sh"
source "${LIBRARY}/exit_codes.sh"

send_packages() {
    local distro="$1" ; shift
    local component="$1" ; shift
    local rsync_opts=("$@")  # hidden gem

    local source_dir="${BUILD_DIR}/${distro}"

    msg "Sending packages: distro=%s component=%s" "$distro" "$component"

    shopt -s globstar nullglob
    debs=("${source_dir}"/**/*.deb)
    shopt -u globstar nullglob

    if [[ ${#debs} -eq 0 ]]; then
        error2 "No debs found in '%s'." "${source_dir}" >&2
        return $E_ERROR
    fi

    remote_dest="${REMOTE_PATH}/${distro}-${component}/"
    rsync -rvz "${rsync_opts[@]}" "${debs[@]}" "${remote_dest}"
}
