#!/bin/bash

# spdx-license-identifier: gpl-3.0-only
# Copyright (C) 2022 Michał Góral

[[ -n "$LIBGPAK_VALIDATE_SH" ]] && return
LIBGPAK_VALIDATE_SH=1

source "${LIBRARY}/message.sh"
source "${LIBRARY}/exit_codes.sh"

validate_config() {
    [[ -z "$PACKAGES_DIR" ]] && { error "PACKAGES_DIR not set" ; exit $E_INVALID_OPTION; }
    [[ ! -d "$DOCKER_CONTEXT" ]] && { error "DOCKER_CONTEXT doesn't point to valid directory" ; exit $E_ERROR; }

    if (( SEND && CACHE )); then
        error "Cache is enabled but sending packages was requested."
        error "This operation is insecure as cached containers might contain"
        error "remaining artifacts from previous builds."
        error "    HINT: use --no-send option"
        (( ! FORCE )) && exit $E_INVALID_OPTION
    fi

    if (( SEND && BUILD_LOCAL )); then
        error "Sending packages was requested but packages are built outside of"
        error "Docker container. This operation is insecure as local machines"
        error "might contain installed software which affects validity of"
        error "PKGBUILD files."
        error "    HINT: use --no-send option"
        (( ! FORCE )) && exit $E_INVALID_OPTION
    fi

    if (( SEND && ! BUILD && CLEAN )); then
        error "Invalid set of flags: --send, --no-build, --clean."
        error "This would remove BUILD_DIR and nothing would be sent."
        exit $E_INVALID_OPTION
    fi
}
